pub fn connect_to_db() -> Result<SqliteConnection, ConnectionError>Expand description
Connect to the default database at the standard location
pub fn connect_to_db() -> Result<SqliteConnection, ConnectionError>Connect to the default database at the standard location