pub fn get_dsi_j_ch_rb_map(paddles: &Vec<TofPaddle>) -> DsiJChRbMappingExpand description
Create a mapping of DSI/J(LTB) -> RBID
This will basically tell you for a given LTB hit which rb has triggered.
pub fn get_dsi_j_ch_rb_map(paddles: &Vec<TofPaddle>) -> DsiJChRbMappingCreate a mapping of DSI/J(LTB) -> RBID
This will basically tell you for a given LTB hit which rb has triggered.