pub struct TofPaddleTimingConstant {
pub data_id: i32,
pub paddle_id: i32,
pub volume_id: i64,
pub utc_timestamp_start: i64,
pub utc_timestamp_stop: i64,
pub name: Option<String>,
pub version: Option<i32>,
pub timing_constant: f32,
}Expand description
Masking of unusable strips as curated by the tracker team
Fields
data_id: i32paddle_id: i32volume_id: i64utc_timestamp_start: i64utc_timestamp_stop: i64name: Option<String>version: Option<i32>timing_constant: f32Implementations
Sourceimpl TofPaddleTimingConstant
impl TofPaddleTimingConstant
pub fn new() -> Self
Sourcepub fn all_names() -> Result<Vec<String>, ConnectionError>
pub fn all_names() -> Result<Vec<String>, ConnectionError>
Retrieve the names under which the timing constants are saved
Sourcepub fn as_dict_by_name(
fname: &str,
) -> Result<HashMap<u8, Self>, ConnectionError>
pub fn as_dict_by_name( fname: &str, ) -> Result<HashMap<u8, Self>, ConnectionError>
Get Tof timing constants as associated with a distinct name
Returns:
- HashMap<u32 [paddle id], Self>